pub enum Error<I2CError> {
ChecksumFailed,
I2C(I2CError),
}Expand description
Any error that can occur when using this library.
Variants
ChecksumFailed
A packet was received from the FS3000 but it’s checksum was invalid. This typically indicates a faulty link or device.
I2C(I2CError)
Any I2C error that occurs when communicating with the device.